/**
 * 年月日 时分秒
 * @param nS 非必填
 * @param reg 非必填
 * @returns yyyy ${reg} mm ${reg} dd hh:mm:ss
 */
function DateFormat_YMD_HMS(nS?: Number | string, reg?: string) {
  const date = nS ? new Date(String(nS)) : new Date();
  const year = date.getFullYear();
  const mon = date.getMonth() + 1;
  const day = date.getDate();
  const hours = date.getHours();
  const minutes = date.getMinutes();
  const seconds = date.getSeconds();

  const monStr = mon > 9 ? mon : '0' + mon;
  const dayStr = day > 9 ? day : '0' + day;
  const hoursStr = hours > 9 ? hours : '0' + hours;
  const minutesStr = minutes > 9 ? minutes : '0' + minutes;
  const secondsStr = seconds > 9 ? seconds : '0' + seconds;
  return year + (reg ? reg : '年') + monStr + (reg ? reg : '月') + dayStr + (reg ? reg : '日') + ' ' + hoursStr + ':' + minutesStr + ':' + secondsStr;
}

/**
 * 年月日
 * @param nS 非必填
 * @param reg 非必填
 * @returns yyyy ${reg} mm ${reg} dd
 */
function DateFormat_YMD(nS?: Number | string, reg?: string) {
  const date = nS ? new Date(String(nS)) : new Date();
  const year = date.getFullYear();
  const mon = date.getMonth() + 1;
  const day = date.getDate();
  const monStr = mon > 9 ? mon : '0' + mon;
  const dayStr = day > 9 ? day : '0' + day;
  return '' + year + (reg ? reg : '年') + monStr + (reg ? reg : '月') + dayStr + (reg ? reg : '日');
}

/**
 * 时分秒
 * @param nS 非必填
 * @returns hh:mm:ss
 */
function DateFormat_HMS(nS?: Number | string) {
  const date = nS ? new Date(String(nS)) : new Date();
  const hours = date.getHours();
  const minutes = date.getMinutes();
  const seconds = date.getSeconds();
  const hoursStr = hours > 9 ? hours : '0' + hours;
  const minutesStr = minutes > 9 ? minutes : '0' + minutes;
  const secondsStr = seconds > 9 ? seconds : '0' + seconds;
  return hoursStr + ':' + minutesStr + ':' + secondsStr;
}

/**
 * 时间戳转换为 xx天xx小时xx分钟xx秒
 * @param timestamp 非必填
 * @returns xx天xx小时xx分钟xx秒
 */
function DateFormat_timestamp(timestamp?: number | string) {
  const newTimestamp = timestamp ? timestamp : new Date().getTime();
  const timestampNum = Number(newTimestamp);
  const second = Math.ceil(timestampNum / 1000);
  const minute = second >= 60 ? Math.floor(second / 60) : 0;
  const hour = minute >= 60 ? Math.floor(minute / 60) : 0;
  const day = hour >= 60 ? Math.floor(hour / 24) : 0;
  const dayStr = day === 0 ? "" : `${day}天`;
  const hourStr = hour % 24 === 0 ? "" : `${hour % 24}小时`;
  const minuteStr = minute % 60 === 0 ? "" : `${minute % 60}分钟`;
  const secondStr = second % 60 === 0 ? "" : `${second % 60}秒`;
  return `${dayStr}${hourStr}${minuteStr}${secondStr}`;
}

/**
 * 指定日期后的几天
 * @param date 非必填
 * @param nextDay 非必填
 * @returns yyyy ${reg} mm ${reg} dd
 */
function DateFormat_nextDate(date?: string, nextDay?: number, reg?: string) {
  let f_date = date ? new Date(date) : new Date();
  f_date = new Date(+f_date + (nextDay ? nextDay : 1) * 24 * 60 * 60 * 1000);
  return DateFormat_YMD(String(f_date), reg || '-');
}


export {
  DateFormat_YMD_HMS,
  DateFormat_YMD,
  DateFormat_HMS,
  DateFormat_timestamp,
  DateFormat_nextDate
}